from .tweet_extract import *
from .graph_plot import *
from .slider import Ui_MainWindow
from PyQt5 import QtWidgets 
import sys
import networkx as nx
import matplotlib.pyplot as plt
##-------------BEGIN INVOKING MODULES------------##

class MainWindow(QtWidgets.QMainWindow):
    H = nx.Graph()
    npostweets = []
    ntotaltweets = []
    nodelist=[]
    files = ['Congress','BJP' ,'TMC', 'CPIM','AAP','RJD','BSP','Samajwadi']
    pos = []
    neg = []
    nums = []
    
    def __init__(self):
            
        print("\n\tDownloading Data")

        for names in MainWindow.files:
            try:
                 downloadcsv(names)
            except:
                pass
        print("\n\tData Downloaded\n\tAnalyzing Data and Plotting Graphs")
        for names in MainWindow.files:
            temp =  readfromcsv(names)
            plotPieChart(temp[0], temp[1], temp[2], temp[3], temp[4], temp[5], temp[6], names, temp[7],temp[8])
            # cloud(temp[8])
            MainWindow.ntotaltweets.append(temp[7])
            MainWindow.npostweets.append(len(temp[9]))
            MainWindow.pos.append(temp[0] + temp[1] + temp[2])
            MainWindow.neg.append(temp[3] + temp[4] + temp[5])
            MainWindow.nums.append(names + '\n' + 'with' +'\n' + str(temp[7]) + '\n' + 'tweets')
            MainWindow.H =  plottest(MainWindow.H, temp[9], names)
        
        #for i in range(len(MainWindow.npostweets)):
            #MainWindow.npostweets[i]= percentage(MainWindow.npostweets[i],MainWindow.ntotaltweets[i])
 
        barGraphP(MainWindow.pos,MainWindow.neg,MainWindow.nums)
        super(MainWindow,self).__init__() #This is the parent window object
        self.ui=Ui_MainWindow()
        self.ui.setupUi(self)
        self.ui.pushButton.clicked.connect(self.kcore)
        def get_key(val):
            for key, value in res.items():
                if val == value :
                    return key
        res = nx.degree_centrality(MainWindow.H)
        temp = []
        for names in MainWindow.files:
            temp.append(res[names])

        print("From calculating the degrees of centrality for the corresponding parties, we find that with ", round(float(max(temp)),3))
        print(" degree of centrality, "+get_key(max(temp))+" has a probable chance of winning.")
        
        
    def kcore(self):
        self.ui.kvalue.setText(str(self.ui.slider.value()))
        G=MainWindow.H.copy()
        self.ui.pushButton.setDisabled(True)
        self.ui.progressBar.setValue(60)
        self.ui.progressBar.setValue(80)
        to_del = [n for n in G if G.degree(n) < self.ui.slider.value()]
        G.remove_nodes_from(to_del)
        nodes=dict(G.degree)
        for v in nodes.values():
            if v<10:
                MainWindow.nodelist.append(v*50)
            else:
                MainWindow.nodelist.append(500)

        nx.draw(G, node_size=MainWindow.nodelist, with_labels=True,alpha=0.8)
        plt.savefig('Network Graph.png',dpi=200)
        plt.show()
        self.ui.progressBar.setValue(100)
        self.ui.pushButton.setDisabled(False)

def main() :
    app = QtWidgets.QApplication(sys.argv)
    w = MainWindow()
    w.show()
    sys.exit(app.exec_())

if __name__ == "__main__":
    main()




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'C:\Users\Devpratim\Desktop\slider.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(386, 253)
        MainWindow.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.slider = QtWidgets.QSlider(self.centralwidget)
        self.slider.setGeometry(QtCore.QRect(30, 70, 331, 35))
        self.slider.setMinimum(1)
        self.slider.setMaximum(10)
        self.slider.setProperty("value", 4)
        self.slider.setOrientation(QtCore.Qt.Horizontal)
        self.slider.setTickPosition(QtWidgets.QSlider.TicksBothSides)
        self.slider.setTickInterval(1)
        self.slider.setObjectName("slider")
        self.progressBar = QtWidgets.QProgressBar(self.centralwidget)
        self.progressBar.setGeometry(QtCore.QRect(30, 190, 331, 23))
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setGeometry(QtCore.QRect(30, 10, 150, 41))
        font = QtGui.QFont()
        font.setPointSize(17)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.pushButton = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton.setGeometry(QtCore.QRect(40, 120, 151, 51))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.pushButton.setFont(font)
        self.pushButton.setObjectName("pushButton")
        self.kvalue = QtWidgets.QLabel(self.centralwidget)
        self.kvalue.setGeometry(QtCore.QRect(250, 110, 61, 51))
        font = QtGui.QFont()
        font.setPointSize(15)
        self.kvalue.setFont(font)
        self.kvalue.setText("")
        self.kvalue.setObjectName("kvalue")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 386, 21))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "K-Value Selector"))
        self.label_4.setText(_translate("MainWindow", "Set k-value"))
        self.pushButton.setText(_translate("MainWindow", "SET"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())




import pandas as pd
from textblob import TextBlob

url='https://raw.githubusercontent.com/itsDevhere/DataRepo/master/'
def downloadcsv(filename):
    tweetfile=pd.read_csv(url+filename+'_cleaned.csv')
    tweetfile.to_csv(filename+'_cleaned.csv',index=False,encoding='utf-8')
def readfromcsv(filename):
    tweetfile=pd.read_csv(filename+'_cleaned.csv')
    tweetText = []
    username = []
    positivetweets=[]
    hash_count=''
    for row in tweetfile.itertuples():
        # Append to temp so that we can store in csv later. I use encode UTF-8
        tweetText.append(row[1])
        username.append(row[2])
        hash_count+=row[3].strip('[]')    
    polarity = 0
    positive = 0
    wpositive = 0
    spositive = 0
    negative = 0
    wnegative = 0
    snegative = 0
    neutral = 0
    n=len(tweetText)
    for i in range(n) :
        analysis = TextBlob(str(tweetText[i]))
        polarity += analysis.sentiment.polarity
        if (analysis.sentiment.polarity == 0):  # adding reaction of how people are reacting to find average later
            neutral += 1
        elif (analysis.sentiment.polarity > 0 and analysis.sentiment.polarity <= 0.3):
            wpositive += 1
            positivetweets.append(username[i])
        elif (analysis.sentiment.polarity > 0.3 and analysis.sentiment.polarity <= 0.6):
            positive += 1
            positivetweets.append(username[i])
        elif (analysis.sentiment.polarity > 0.6 and analysis.sentiment.polarity <= 1):
            spositive += 1
            positivetweets.append(username[i])
        elif (analysis.sentiment.polarity > -0.3 and analysis.sentiment.polarity <= 0):
            wnegative += 1
        elif (analysis.sentiment.polarity > -0.6 and analysis.sentiment.polarity <= -0.3):
            negative += 1
        elif (analysis.sentiment.polarity > -1 and analysis.sentiment.polarity <= -0.6):
            snegative += 1
    
    # finding average of how people are reacting
    positive = percentage(positive, n)
    wpositive = percentage(wpositive, n)
    spositive = percentage(spositive, n)
    negative = percentage(negative, n)
    wnegative = percentage(wnegative, n)
    snegative = percentage(snegative, n)
    neutral = percentage(neutral, n)
    polarity = polarity / len(tweetText)

    print("\nAnalyzing " +str( n) + " tweets on " + filename)
    print("General Report: ")

    if (polarity == 0):
        print("Neutral")
    elif (polarity > 0 and polarity <= 0.3):
        print("Weakly Positive")
    elif (polarity > 0.3 and polarity <= 0.6):
        print("Positive")
    elif (polarity > 0.6 and polarity <= 1):
        print("Strongly Positive")
    elif (polarity > -0.3 and polarity <= 0):
        print("Weakly Negative")
    elif (polarity > -0.6 and polarity <= -0.3):
        print("Negative")
    elif (polarity > -1 and polarity <= -0.6):
        print("Strongly Negative")

    print("\nDetailed Report: \n")
    print(str(positive) + "% people thought it was positive")
    print(str(wpositive) + "% people thought it was weakly positive")
    print(str(spositive) + "% people thought it was strongly positive")
    print(str(negative) + "% people thought it was negative")
    print(str(wnegative) + "% people thought it was weakly negative")
    print(str(snegative) + "% people thought it was strongly negative")
    print(str(neutral) + "% people thought it was neutral")
    temp=[positive, wpositive, spositive, negative, wnegative, snegative, neutral, n,hash_count,positivetweets]
    return temp

def percentage(part, whole):
#--Percentage conversion upto 2 decimal places--#    
    temp = 100 * float(part) / float(whole)
    return round(temp,2)
    #return format(temp, '.2f')



from wordcloud import WordCloud
import matplotlib.pyplot as plt
import numpy as np

def plotPieChart(positive, wpositive, spositive, negative, wnegative,snegative, neutral, searchTerm, noOfSearchTerms,hash_tag):
#--Create pie chart--#
    fig = plt.figure(figsize=(10, 4), dpi=130)
    ax1 = fig.add_subplot(1, 2, 1, title="\nAnalyzing " + str(noOfSearchTerms) + " tweets on " + searchTerm)
    ax2 = fig.add_subplot(1, 2, 2, title='Frequent hashtags from Tweets fetched.\n')
    labels = ['Positive [' + str(positive) + '%]', 'Weakly Positive [' + str(wpositive) + '%]', 'Strongly Positive [' + str(spositive) + '%]', 'Neutral [' + str(neutral) + '%]',
              'Negative [' + str(negative) + '%]', 'Weakly Negative [' + str(wnegative) + '%]', 'Strongly Negative [' + str(snegative) + '%]']
    sizes = [positive, wpositive, spositive, neutral, negative, wnegative, snegative]
    colors = ['yellowgreen', 'lightgreen', 'darkgreen', 'gold', 'red', 'lightsalmon', 'darkred']
    ax1.pie(sizes, colors=colors, startangle=90)
    ax1.legend(labels, loc="best", fontsize=7 ) #Changes to code from plt.legend(patches, labels, loc="best")
    #ax1.title("\nAnalyzing " + str(noOfSearchTerms) + " tweets on " + searchTerm)
    ax1.axis('equal')
    #ax1.tight_layout()
    wc = WordCloud(width=1500, height=1200, background_color="white", relative_scaling=0.5).generate(hash_tag)
    ax2.imshow(wc, interpolation='bilinear')
    ax2.axis('off')
    #ax2.title('Frequent hashtags from Tweets fetched.', color='black')
    plt.show()

def barGraphP(pos,neg,nums):
    n = 8
    X = np.arange(n)
    #pos=[]
    #neg=[]
    #for name in files:
        #pos.append(temp[0] + temp[1] + temp[2])
        #neg.append(temp[3] + temp[4] + temp[5])
        #nums.append(name + '\n' + 'with' +'\n' + str(temp[7]) + '\n' + 'tweets')    
    YP = np.array(pos)
    YN = np.array(neg)
    #plt.axes([2, 2, 0.95, 0.95]) not supported with tight layout
    plt.figure(figsize=(10, 5))
    plt.bar(X, +YP, facecolor='#9999ff', edgecolor='white', label='positive tweets',width = 0.7)
    plt.bar(X, -YN, facecolor='#ff9999', edgecolor='white', label='negative tweets',width = 0.7)
    plt.legend(loc='upper right')
    plt.ylim(-40,60)
    for x, y in zip(X, YP):
        plt.text(x , y + 0.05, '%.2f' % y + '%', ha='center', va= 'bottom')
    for x, y in zip(X, YN):
        plt.text(x , -y - 0.1, '%.2f' % y + '%', ha='center', va= 'top')
    plt.title("\nAnalyzing positive and negative tweet percentage ")
    plt.xticks(X, nums, fontsize=12)
    plt.tight_layout()
    plt.show()

def plottest(Gr,nodelist,mainnode):
    nodelist=list(dict.fromkeys(nodelist))
    Gr.add_nodes_from(nodelist)
    for i in range(len(nodelist)):
        Gr.add_edge(nodelist[i],mainnode)
    return Gr





from setuptools import setup
def readme():
    with open('README.md') as f:
        README = f.read()
    return README

setup(
    name="sna_prediction",
    version="1.1",
    description="A python package to predict outcome of an event based on type of data it is fed to.For now it is Loksabha 2019 Elections",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/itsDevhere/social-network-analysis",
    author="Devpratim Das , Rana Mondal , Souvik Das , Soumyajeet Bose",
    author_email="",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3"],
    packages=["sna_prediction"],
    include_package_data=False,
    install_requires=["tweepy","textblob","wordcloud","PyQt5","pandas","numpy","networkx==2.3","matplotlib","emoji"],
    entry_points={
        "console_scripts": [
            "sna_prediction=sna_prediction.main:main",
        ]
    },
)